# Plug-in Registration

Plug-in commands register kernel and GUI plug-ins in either the Plug-ins menu or in a toolbox. Plug-in registration commands for accessing both kernel and GUI plug-ins are located in the Abaqus GUI Toolkit Reference Guide.

## Classes

### Other Classes

```{eval-rst}

.. toggle::

    .. automembers:: abaqus.PlugInRegistration
        :recursive:

    .. placeholder for empty members
```
